(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "stream", "zipson"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const stream_1 = require("stream");
    const zipson_1 = require("zipson");
    class ZipsonStreamWriter extends zipson_1.ZipsonWriter {
        constructor(bufferThreshold = 250) {
            super();
            this.bufferThreshold = bufferThreshold;
            this._stream = new stream_1.PassThrough();
            this._buffer = '';
        }
        write(data) {
            this._buffer += data;
            if (this._buffer.length > this.bufferThreshold) {
                this._stream.push(this._buffer);
                this._buffer = '';
            }
        }
        end() {
            if (this._buffer.length > 0) {
                this._stream.push(this._buffer);
                this._buffer = '';
            }
            this._stream.push(null);
        }
        get stream() {
            return this._stream;
        }
    }
    exports.ZipsonStreamWriter = ZipsonStreamWriter;
});
//# sourceMappingURL=ZipsonStreamPackWriter.js.map